@@ -8,6 +8,8 @@ from lightning_cloud.openapi.api.cluster_service_api import ClusterServiceApi
 from lightning_cloud.openapi.api.lightningapp_instance_service_api import LightningappInstanceServiceApi
 from lightning_cloud.openapi.api.lightningapp_v2_service_api import LightningappV2ServiceApi
 from lightning_cloud.openapi.api.lightningwork_service_api import LightningworkServiceApi
+from lightning_cloud.openapi.api.models_store_api import ModelsStoreApi
 from lightning_cloud.openapi.api.projects_service_api import ProjectsServiceApi
+from lightning_cloud.openapi.api.ssh_public_key_service_api import SSHPublicKeyServiceApi
 from lightning_cloud.openapi.api.secret_service_api import SecretServiceApi
 from lightning_cloud.openapi.api.user_service_api import UserServiceApi
